@@ -1,10 +1,12 @@
-__version__ = "0.3.4"
+__version__ = "0.3.8"
 
 from .io import yaml_load, yaml_dump, save, load, json_load, json_dump
 from .path import *
 from .progress_bar import probar
 from .performance import MeasureTime
 from .async_api import ConcurrentRequester
+from .nlp.parser import parse_to_obj, parse_to_code
+from .ai_platform.metrics import MetricsCalculator, save_pred_metrics
 # from .decorators import benchmark
 # from .string.color_string import rgb_string
 # from .functions.core import clamp, topk, dict_topk
