@@ -5,6 +5,8 @@ import pretty_errors
 import rich
 from typing import Literal, Tuple
 from pathlib import Path
+import datetime
+
 
 class Cli:
     def __init__(self):
@@ -12,7 +14,13 @@ class Cli:
             "server": "http://127.0.0.1:8000",
             "croc_relay": "142.171.214.153:27011"
         }
-        self.flaxkv_server = os.environ.get("FLAXKV_SERVER")
+        from sparrow import yaml_load
+        try:
+            self.sparrow_config = yaml_load("sparrow_config.yaml")
+        except Exception:
+            self.sparrow_config = {}
+
+        self.flaxkv_server = self.sparrow_config.get("flaxkv_server", os.environ.get("FLAXKV_SERVER"))
         if self.flaxkv_server:
             from flaxkv import FlaxKV
             self._db = FlaxKV(db_name="sparrow", root_path_or_url=self.flaxkv_server, show_progress=True)
@@ -21,25 +29,51 @@ class Cli:
 
 
     def set(self, key: str, filepath: str):
+        def _get_file_metadata(filepath: str) -> dict:
+            file_stat = os.stat(filepath)
+            return {
+                "size": file_stat.st_size,
+                "created_time": datetime.datetime.fromtimestamp(file_stat.st_ctime).isoformat(),
+                "modified_time": datetime.datetime.fromtimestamp(file_stat.st_mtime).isoformat(),
+                "accessed_time": datetime.datetime.fromtimestamp(file_stat.st_atime).isoformat(),
+            }
+        
         with open(filepath, 'rb') as f:
             content = f.read()
-        self._db[key] = {"filename": Path(filepath).name, "content": content}
+        self._db[key] = {
+            "filename": Path(filepath).name,
+            "content": content, 
+            "metadata": _get_file_metadata(filepath)
+            }
         self._db.write_immediately(block=True)
 
     def keys(self):
         from .string.color_string import rgb_string, color_const
         print(rgb_string(str(list(self._db.keys())), color_const.GREEN))
 
-
-    def get(self, key: str):
+    def get(self, key: str, delete=False):
         from .string.color_string import rgb_string
-        data = self._db.pop(key, None)
+        data = self._db[key] if key in self._db else None
         if data:
             with open(data["filename"], 'wb') as f:
                 f.write(data["content"])
+            if delete:
+                del self._db[key]
+                self._db.write_immediately(block=True)
         else:
             print(rgb_string(f"WARNING: {key} not found"))
 
+    def info(self, key: str):
+        from .string.color_string import rgb_string, color_const
+        data = self._db.get(key)
+        if data:
+            print(rgb_string(f"Key: {key}", color_const.BLUE))
+            print(rgb_string(f"Filename: {data['filename']}", color_const.BLUE))
+            print(rgb_string(f"Size: {len(data['content'])} bytes", color_const.BLUE))
+            print(rgb_string(f"Metadata: {data.get('metadata', {})}", color_const.BLUE))
+        else:
+            print(rgb_string(f"WARNING: {key} not found", color_const.RED))
+
     def clean(self):
         raise NotImplementedError
 
